@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -55,7 +55,7 @@ __all__ = ("CloudHSMClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -69,7 +69,7 @@ class Exceptions:
 
 class CloudHSMClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html)
     """
 
@@ -82,12 +82,12 @@ class CloudHSMClient(BaseClient):
         """
 
     def add_tags_to_resource(
-        self, *, ResourceArn: str, TagList: List["TagTypeDef"]
+        self, *, ResourceArn: str, TagList: Sequence["TagTypeDef"]
     ) -> AddTagsToResourceResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#add_tags_to_resource)
         """
 
@@ -95,7 +95,7 @@ class CloudHSMClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#can_paginate)
         """
 
@@ -103,7 +103,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_hapg)
         """
 
@@ -122,7 +122,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_hsm)
         """
 
@@ -132,7 +132,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_luna_client)
         """
 
@@ -140,7 +140,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_hapg)
         """
 
@@ -148,7 +148,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_hsm)
         """
 
@@ -156,7 +156,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_luna_client)
         """
 
@@ -164,7 +164,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_hapg)
         """
 
@@ -174,7 +174,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_hsm)
         """
 
@@ -184,31 +184,31 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_luna_client)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#generate_presigned_url)
         """
 
     def get_config(
-        self, *, ClientArn: str, ClientVersion: ClientVersionType, HapgList: List[str]
+        self, *, ClientArn: str, ClientVersion: ClientVersionType, HapgList: Sequence[str]
     ) -> GetConfigResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#get_config)
         """
 
@@ -216,7 +216,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_available_zones)
         """
 
@@ -224,7 +224,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_hapgs)
         """
 
@@ -232,7 +232,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_hsms)
         """
 
@@ -240,7 +240,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_luna_clients)
         """
 
@@ -248,17 +248,17 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_tags_for_resource)
         """
 
     def modify_hapg(
-        self, *, HapgArn: str, Label: str = None, PartitionSerialList: List[str] = None
+        self, *, HapgArn: str, Label: str = None, PartitionSerialList: Sequence[str] = None
     ) -> ModifyHapgResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_hapg)
         """
 
@@ -275,7 +275,7 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_hsm)
         """
 
@@ -285,31 +285,31 @@ class CloudHSMClient(BaseClient):
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_luna_client)
         """
 
     def remove_tags_from_resource(
-        self, *, ResourceArn: str, TagKeyList: List[str]
+        self, *, ResourceArn: str, TagKeyList: Sequence[str]
     ) -> RemoveTagsFromResourceResponseTypeDef:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#remove_tags_from_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hapgs"]) -> ListHapgsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhapgspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hsms"]) -> ListHsmsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhsmspaginator)
         """
 
@@ -318,6 +318,6 @@ class CloudHSMClient(BaseClient):
         self, operation_name: Literal["list_luna_clients"]
     ) -> ListLunaClientsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.40/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listlunaclientspaginator)
         """
